==> openapi-2.4.0304-sources.jar: com/zing/zalo/zalosdk/oauth/OpenAPIActivity.java <==
package com.zing.zalo.zalosdk.oauth;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;

public class OpenAPIActivity extends Activity {

    private class LoginListener extends OAuthCompleteListener {
        String a;
        boolean b = false;
        final /* synthetic */ OpenAPIActivity c;

        public LoginListener(OpenAPIActivity openAPIActivity, String shareTo, boolean _autoBack) {
            this.c = openAPIActivity;
            this.a = shareTo;
            this.b = _autoBack;
        }

        public void onAuthenError(int errorCode, String message) {
            super.onAuthenError(errorCode, message);
            if (OpenAPIService.getInstance().a != null) {
                ZaloPluginCallback callback = (ZaloPluginCallback) OpenAPIService.getInstance().a.get();
                if (callback != null) {
                    callback.onResult(false, errorCode, message, "");
                }
            }
            this.c.finish();
        }

        public void onGetOAuthComplete(OauthResponse response) {
            super.onGetOAuthComplete(response);
            OpenAPIService op = OpenAPIService.getInstance();
            if (op.a != null) {
                ZaloPluginCallback callback = (ZaloPluginCallback) op.a.get();
                Context context = (Context) op.b.get();
                if (!(callback == null || context == null)) {
                    op._shareTo = this.a;
                    op._autoBack = this.b;
                    op.a(context, op.c, callback, op._shareTo, op._autoBack);
                }
            }
            this.c.finish();
        }
    }

    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        boolean login_from_share_feed = getIntent().getBooleanExtra("login_from_share_feed", false);
        String shareTo = getIntent().getStringExtra("share_to");
        boolean _autoBack = getIntent().getBooleanExtra("autoBack", false);
        if (login_from_share_feed) {
            ZaloSDK.Instance.authenticateZaloPlugin(this, new LoginListener(this, shareTo, _autoBack));
        }
    }

    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        ZaloSDK.Instance.onActivityResult(this, requestCode, resultCode, data);
    }
}

==> openapi-2.4.0520-sources.jar: com/zing/zalo/zalosdk/oauth/OpenAPIActivity.java <==
package com.zing.zalo.zalosdk.oauth;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;

public class OpenAPIActivity extends Activity {
    LoginListener a;

    private class LoginListener extends OAuthCompleteListener {
        String a;
        boolean b = false;
        final /* synthetic */ OpenAPIActivity c;

        public LoginListener(OpenAPIActivity openAPIActivity, String shareTo, boolean _autoBack) {
            this.c = openAPIActivity;
            this.a = shareTo;
            this.b = _autoBack;
        }

        public void onAuthenError(int errorCode, String message) {
            super.onAuthenError(errorCode, message);
            if (OpenAPIService.getInstance().a != null) {
                ZaloPluginCallback callback = (ZaloPluginCallback) OpenAPIService.getInstance().a.get();
                if (callback != null) {
                    callback.onResult(false, errorCode, message, "");
                }
            }
            this.c.finish();
        }

        public void onGetOAuthComplete(OauthResponse response) {
            super.onGetOAuthComplete(response);
            OpenAPIService op = OpenAPIService.getInstance();
            if (op.a != null) {
                ZaloPluginCallback callback = (ZaloPluginCallback) op.a.get();
                Context context = (Context) op.b.get();
                if (!(callback == null || context == null)) {
                    op._shareTo = this.a;
                    op._autoBack = this.b;
                    op.a(context, op.c, callback, op._shareTo, op._autoBack);
                }
            }
            this.c.finish();
        }
    }

    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        boolean login_from_share_feed = getIntent().getBooleanExtra("login_from_share_feed", false);
        String shareTo = getIntent().getStringExtra("share_to");
        boolean _autoBack = getIntent().getBooleanExtra("autoBack", false);
        if (login_from_share_feed) {
            this.a = new LoginListener(this, shareTo, _autoBack);
            ZaloSDK.Instance.authenticateZaloPlugin(this, this.a);
        }
    }

    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        ZaloSDK.Instance.onActivityResult(this, requestCode, resultCode, data);
    }
}
